@@ -21,7 +21,7 @@ TODO: add transform( matrix )
 TODO: add point_within_aabb
 TODO: use point_within_aabb for unit tests
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import absolute_import, division, print_function
 import numpy as np
 from . import aabb, vector
 from .utils import all_parameters_as_numpy_arrays, parameters_as_numpy_arrays
